@@ -1,8 +1,8 @@
 """
    SDC subscription model module
 """
-from sqlalchemy import Column, Integer, ForeignKey, JSON, String
-from sqlalchemy.orm import relationship, deferred, query_expression
+from sqlalchemy import Column, Integer, ForeignKey, JSON, String, DateTime
+from sqlalchemy.orm import relationship, query_expression
 from sdc_helpers.models.model import Model, models_namespace
 
 
@@ -15,10 +15,9 @@ class Subscription(Model):
 
     client_id = Column(Integer, ForeignKey('clients.id'), primary_key=True)
     service_id = Column(Integer, ForeignKey('services.id'), primary_key=True)
-    # by default lazy load properties to avoid large data stores from automatically being pulled
-    # at query time - use .options(undefer('properties')) on query to override default behaviour
-    properties = deferred(Column(JSON))
+    properties = Column(JSON)
     updated_by = Column(String(255))
+    deleted_at = Column(DateTime)
     properties_node = query_expression()
 
     client = relationship(
